@@ -1,60 +1,48 @@
 #' Convert MIDI to LilyPond file
 #'
-#' Convert a MIDI file (\code{.mid}) to a LilyPond format (\code{.ly}) text
-#' file.
+#' Convert a MIDI file (`.mid`) to a LilyPond format (`.ly`) text file.
 #'
 #' Under development/testing. See warning and details below.
 #'
-#' This function is a wrapper around the \code{midi2ly} command line utility
+#' This function is a wrapper around the `midi2ly()` command line utility
 #' provided by LilyPond. It inherits all the limitations thereof.
 #' LilyPond is not intended to be used to produce meaningful sheet music from
 #' arbitrary MIDI files.
-#' While \code{\link{lilypond}} converts R code \code{score} objects to
-#' LilyPond markup directly, MIDI conversion to LilyPond markup by
-#' \code{midily} requires LilyPond.
+#' While [lilypond()] converts R code `score()` objects to LilyPond markup
+#' directly, MIDI conversion to LilyPond markup by `midily()` requires LilyPond.
 #'
 #' WARNING: Even though the purpose of the command line utility is to convert
 #' an existing MIDI file to a LilyPond file, it nevertheless generates a
-#' LilyPond file that \emph{specifies inclusion of MIDI output}.
+#' LilyPond file that *specifies inclusion of MIDI output*.
 #' This means when you subsequently process the LilyPond file with LilyPond or
-#' if you use \code{miditab} to go straight from your MIDI file to pdf output,
+#' if you use `miditab()` to go straight from your MIDI file to pdf output,
 #' the command line tool will also produce a MIDI file output. It will
 #' overwrite your original MIDI file if it has the same file name and location!
-#' The next version of this function will add an default argument
-#' \code{midi_out = FALSE} to remove this from the generated LilyPond file.
-#' If \code{TRUE} and the basename of \code{midi_file} matches the basename of
-#' \code{file}, then \code{file} will be renamed, the basename appended with a
-#' \code{-1}.
 #'
-#' \code{allow_tuplets = NULL} to disallow all tuplets. Fourth, eighth and
-#' sixteenth note triplets are allowed. The format is a character vector where
-#' each element is \code{duration*numerator/denominator}, no spaces.
-#' See default argument.
+#' `allow_tuplets = NULL` to disallow all tuplets. Fourth, eighth and sixteenth
+#' note triplets are allowed. The format is a character vector where each
+#' element is `duration*numerator/denominator`, no spaces. See default argument.
 #'
-#' On Windows systems, it may be necessary to specify a path in tabr_options to
-#' both \code{midi2ly} and \code{python} if they are not already successfully
-#' set as follows.
-#' On package load, \code{tabr} will attempt to check for \code{midi2ly.exe} at
-#' \code{C:/Program Files (x86)/LilyPond/usr/bin/midi2ly.py} and similarly for
-#' the \code{python.exe} that ships with LilyPond at
-#' \code{C:/Program Files (x86)/LilyPond/usr/bin/python.exe}.
-#' If this is not where LilyPond is installed, then LilyPond and Python need to
-#' be provided to \code{tabr_options} or added to the system PATH variable.
+#' On Windows systems, it may be necessary to specify a path in [tabr_options()]
+#' to both `midi2ly` and `python` if they are not already added to the system
+#' PATH variable.
 #'
-#' @param midi_file character, MIDI file (\code{.mid}). May include an absolute
-#' or relative path.
-#' @param file LilyPond output file ending in \code{.ly}.
-#' @param key key signature, defaults to \code{"c"}.
-#' @param absolute logical, print absolute pitches.
+#' @param midi_file character, MIDI file (`.mid`). May include an absolute or
+#' relative path.
+#' @param file LilyPond output file ending in `.ly`.
+#' @param key key signature, defaults to `"c"`.
+#' @param absolute logical, print absolute pitches (unavailable in current
+#' package version).
 #' @param quantize integer, duration, quantize notes on duration.
 #' @param explicit logical, print explicit durations.
 #' @param start_quant integer, duration, quantize note starts on the duration.
 #' @param allow_tuplet character vector, allow tuplet durations. See details.
+#' @param details logical, print additional information to console.
 #' @param lyric logical, treat all text as lyrics.
 #'
 #' @return nothing returned; a file is written.
 #' @export
-#' @seealso \code{\link{miditab}}, \code{\link{tab}}, \code{\link{lilypond}}
+#' @seealso [miditab()], [tab()], [lilypond()]
 #'
 #' @examples
 #' \dontrun{
@@ -66,10 +54,12 @@
 #' }
 midily <- function(midi_file, file, key = "c", absolute = FALSE,
                    quantize = NULL, explicit = FALSE, start_quant = NULL,
-                   allow_tuplet = c("4*2/3", "8*2/3", "16*2/3"), lyric = FALSE){
+                   allow_tuplet = c("4*2/3", "8*2/3", "16*2/3"),
+                   details = FALSE, lyric = FALSE){
   .check_lilypond()
   x <- paste0("--key=", .midily_key(key))
-  if(absolute) x <- paste(x, "--absolute-pitches")
+  # if(absolute) x <- paste(x, "--absolute-pitches")
+  if(absolute) message("--absolute-pitches CL arg is ignored in current tabr version.")
   if(!is.null(quantize)) x <- paste(x, paste0("--duration-quant=", quantize))
   if(explicit) x <- paste(x, "--explicit-durations")
   if(!is.null(start_quant)) x <- paste(x, paste0("--start-quant=", start_quant))
@@ -77,8 +67,8 @@ midily <- function(midi_file, file, key = "c", absolute = FALSE,
     for(i in seq_along(allow_tuplet))
       x <- paste(x, paste0("--allow-tuplet=", allow_tuplet[i]))
   }
-  if(explicit) x <- paste(x, "--verbose")
-  if(explicit) x <- paste(x, "--text-lyrics")
+  if(details) x <- paste(x, "--verbose")
+  if(lyric) x <- paste(x, "--text-lyrics")
   is_windows <- Sys.info()[["sysname"]] == "Windows"
   py_path <- tabr_options()$python
   if(py_path == ""){
@@ -110,44 +100,33 @@ midily <- function(midi_file, file, key = "c", absolute = FALSE,
 #'
 #' Convert a MIDI file to a pdf or png music score using the LilyPond music
 #' engraving program.
-#' Output format is inferred from \code{file} extension. This function is a
-#' wrapper around \code{\link{midily}}, the function that converts the MIDI
-#' file to a LilyPond (\code{.ly}) file using a LilyPond command line utility.
+#' Output format is inferred from `file` extension. This function is a wrapper
+#' around [midily()], the function that converts the MIDI file to a LilyPond
+#' (`.ly`) file using a LilyPond command line utility.
 #'
 #' WARNING: Even though the purpose of the command line utility is to convert
 #' an existing MIDI file to a LilyPond file, it nevertheless generates a
-#' LilyPond file that \emph{specifies inclusion of MIDI output}.
+#' LilyPond file that *specifies inclusion of MIDI output*.
 #' This means when you subsequently process the LilyPond file with LilyPond or
-#' if you use \code{miditab} to go straight from your MIDI file to pdf output,
+#' if you use `miditab()` to go straight from your MIDI file to pdf output,
 #' the command line tool will also produce a MIDI file output. It will
 #' overwrite your original MIDI file if it has the same file name and location!
-#' The next version of this function will add an default argument
-#' \code{midi_out = FALSE} to remove this from the generated LilyPond file.
-#' If \code{TRUE} and the basename of \code{midi_file} matches the basename of
-#' \code{file}, then \code{file} will be renamed, the basename appended with a
-#' \code{-1}.
 #'
-#' On Windows systems, it may be necessary to specify a path in tabr_options to
-#' both \code{midi2ly} and \code{python} if they are not already successfully
-#' set as follows.
-#' On package load, \code{tabr} will attempt to check for \code{midi2ly.exe} at
-#' \code{C:/Program Files (x86)/LilyPond/usr/bin/midi2ly.py} and similarly for
-#' the \code{python.exe} that ships with LilyPond at
-#' \code{C:/Program Files (x86)/LilyPond/usr/bin/python.exe}.
-#' If this is not where LilyPond is installed, then LilyPond and Python need to
-#' be provided to \code{tabr_options} or added to the system PATH variable.
+#' On Windows systems, it may be necessary to specify a path in [tabr_options()]
+#' to both `midi2ly` and `python` if they are not already added to the system
+#' PATH variable.
 #'
-#' @param midi_file character, MIDI file (\code{.mid}). May include an absolute
+#' @param midi_file character, MIDI file (`.mid`). May include an absolute
 #' or relative path.
 #' @param file character, output file ending in .pdf or .png.
 #' @param keep_ly logical, keep LilyPond file.
-#' @param details logical, set to \code{TRUE} to print LilyPond log output to
+#' @param details logical, set to `TRUE` to print LilyPond log output to
 #' console. Windows only.
-#' @param ... additional arguments passed to \code{\link{midily}}.
+#' @param ... additional arguments passed to [midily()].
 #'
 #' @return nothing returned; a file is written.
 #' @export
-#' @seealso \code{\link{midily}}, \code{\link{tab}}, \code{\link{lilypond}}
+#' @seealso [midily()], [tab()], [lilypond()]
 #'
 #' @examples
 #' \dontrun{
@@ -182,24 +161,23 @@ miditab <- function(midi_file, file, keep_ly = FALSE, details = FALSE, ...){
 #' Read MIDI file into a data frame and inspect the music data with supporting
 #' functions.
 #'
-#' The \code{read_midi} function wraps around \code{tuneR::readMidi} by Uwe
-#' Ligges and Johanna Mielke. \code{midi_notes} is a work in progress, but
-#' converts MIDI data to noteworthy strings and note info formats. This makes
-#' it easy to analyze, transform and edit the music data as well as render it
-#' to sheet music and a new MIDI file.
+#' The `read_midi()` function wraps around `tuneR::readMidi()` by Uwe Ligges and
+#' Johanna Mielke. `midi_notes()` is a work in progress, but converts MIDI data
+#' to noteworthy strings and note info formats. This makes it easy to analyze,
+#' transform and edit the music data as well as render it to sheet music and a
+#' new MIDI file.
 #'
-#' \code{read_midi} does not parse the ticks per quarter note from the MIDI
-#' file input at this time. It must be specified with \code{ticks_per_qtr}
+#' `read_midi()` does not parse the ticks per quarter note from the MIDI file
+#' input at this time. It must be specified with `ticks_per_qtr`.
 #'
 #' @param file character, path to MIDI file.
-#' @param x a data frame returned by \code{read_midi}. An integer vector for
-#' \code{ticks_to_duration}; a character vector (may be a space-delimited
-#' string) for \code{duration_to_ticks}.
+#' @param x a data frame returned by `read_midi()`. An integer vector for
+#' `ticks_to_duration()`; a character vector (may be a space-delimited string)
+#' for `duration_to_ticks()`.
 #' @param ticks_per_qtr ticks per quarter note. Used to compute durations from
 #' MIDI file ticks.
 #' @param channel,track integer, filter rows on channel or track.
-#' @param noteworthy logical, convert to \code{noteworthy} and \code{noteinfo}
-#' data.
+#' @param noteworthy logical, convert to `noteworthy` and `noteinfo` data.
 #'
 #' @return a tibble data frame
 #' @export
@@ -224,7 +202,7 @@ miditab <- function(midi_file, file, keep_ly = FALSE, details = FALSE, ...){
 #'   # requires LilyPond installation
 #'   if(tabr_options()$lilypond != ""){
 #'     out <- file.path(tempdir(), "out.pdf")
-#'     phrase(x) %>% track_bc() %>% score() %>% tab(out, details = FALSE)
+#'     phrase(x) |> track_bc() |> score() |> tab(out, details = FALSE)
 #'   }
 #' }
 read_midi <- function(file, ticks_per_qtr = 480){
@@ -236,15 +214,17 @@ read_midi <- function(file, ticks_per_qtr = 480){
   x <- tibble::as_tibble(tuneR::readMidi(file))
   y <- tuneR::getMidiNotes(x)
   bycols <- c("channel", "track", "time", parameter1 = "note")
-  d <- dplyr::left_join(x, y, by = bycols) %>%
-    dplyr::select(-c("notename")) %>%
+  d <- dplyr::left_join(x, y, by = bycols) |>
+    dplyr::select(-dplyr::all_of(c("notename"))) |>
     dplyr::mutate(
       pitch = semitone_pitch(.data[["parameter1"]]),
       pitch = ifelse(.data[["event"]] == "Note On", .data[["pitch"]], NA),
-      duration = ticks_to_duration(.data[["length"]], ticks_per_qtr)) %>%
-    dplyr::select(c("time", "length", "duration", "event", "type", "channel",
-                    "parameter1", "parameter2",
-                    "parameterMetaSystem", "track", "pitch", "velocity"))
+      duration = ticks_to_duration(.data[["length"]], ticks_per_qtr)) |>
+    dplyr::select(dplyr::all_of(
+      c("time", "length", "duration", "event", "type", "channel", "parameter1",
+        "parameter2", "parameterMetaSystem", "track", "pitch", "velocity"
+      )
+    ))
   idx <- which(is.na(d$duration) & d$event == "Note On")
   if(length(idx)){
     d$duration[idx] <- purrr::map_chr(d$length[idx], ~{
@@ -268,22 +248,23 @@ midi_metadata <- function(x){
 #' @export
 #' @rdname read_midi
 midi_notes <- function(x, channel = NULL, track = NULL, noteworthy = TRUE){
-  x <- dplyr::filter(x, .data[["event"]] == "Note On") %>%
-    dplyr::rename(semitone = .data[["parameter1"]]) %>%
-    dplyr::select(c("time", "length", "duration", "pitch", "semitone",
-                    "velocity", "channel", "track"))
+  x <- dplyr::filter(x, .data[["event"]] == "Note On") |>
+    dplyr::rename(semitone = dplyr::all_of("parameter1")) |>
+    dplyr::select(dplyr::all_of(
+      c("time", "length", "duration", "pitch", "semitone","velocity", "channel", "track")
+    ))
 
   if(!is.null(channel))
     x <- dplyr::filter(x, .data[["channel"]] %in% !! channel)
   if(!is.null(track))
     x <- dplyr::filter(x, .data[["track"]] %in% !! track)
   if(noteworthy){
-    x <- dplyr::group_by(x, .data[["time"]]) %>%
+    x <- dplyr::group_by(x, .data[["time"]]) |>
       dplyr::summarize(
         duration = unique(.data[["duration"]]),
         pitch = paste(.data[["pitch"]][order(.data[["semitone"]])],
-                      collapse = "")) %>%
-      dplyr::select(-.data[["time"]])
+                      collapse = "")) |>
+      dplyr::select(-dplyr::all_of("time"))
     idx <- grep(";", x$duration)
     if(length(idx)){
       while(length(idx)){
